@@ -343,6 +343,7 @@ appstream_cache_add_item (AppstreamCacheHelper *helper)
 	AppstreamApp *item;
 	AppstreamCachePrivate *priv = helper->cache->priv;
 	const gchar *id;
+	const gchar *pkgname;
 
 	/* is app compatible with this running desktop */
 	id = appstream_app_get_id (helper->item_temp);
@@ -365,9 +366,12 @@ appstream_cache_add_item (AppstreamCacheHelper *helper)
 	g_hash_table_insert (priv->hash_id,
 			     (gpointer) appstream_app_get_id (helper->item_temp),
 			     helper->item_temp);
-	g_hash_table_insert (priv->hash_pkgname,
-			     (gpointer) appstream_app_get_pkgname (helper->item_temp),
-			     helper->item_temp);
+	pkgname = appstream_app_get_pkgname (helper->item_temp);
+	if (pkgname != NULL) {
+		g_hash_table_insert (priv->hash_pkgname,
+				     (gpointer) pkgname,
+				     helper->item_temp);
+	}
 }
 
 /**
